from setuptools import setup, find_packages
import sys, os

version = '0.0.1'

setup(
    name='virtstrap-npm',
    version=version,
    description="A virtstrap plugin that installs node dependencies",
    long_description="""A virtstrap plugin that installs node packages""",
    classifiers=[],
    keywords='virtstrap ruby bundler virtualenv pip',
    author='Reuven V. Gonzales',
    author_email='reuven@tobetter.us',
    url='http://github.com/ravenac95/virtstrap-npm',
    license='MIT',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'virtstrap-local',
    ],
    entry_points={
        'virtstrap_local.plugins': [
            'npm = virtstrap_npm.plugin',
        ]
    },
)



from __future__ import with_statement
from virtstrap import hooks
from virtstrap.log import logger
from virtstrap.utils import call_subprocess, in_directory


@hooks.create('install', ['after'])
def install_npm_packages(event, options, project=None, **kwargs):
    # ensure we're in the project's root directory
    with in_directory(project.path()):
        try:
            call_subprocess(['command', '-v', 'npm'], show_stdout=False)
        except OSError:
            logger.warning('Skipping node requirements. '
                    'npm must be installed on your system')
            return
        # Installs the bundle requirements and the bins for each
        # requirement in the project's bin path
        call_subprocess(['npm', 'install'])


@hooks.create('environment', ['after'])
def add_npm_bin_path(event, options, project=None, **kwargs):
    env_file_path = options.env_file
    env_file = open(env_file_path, 'a')
    env_file.write('\n# EXTEND PATH WITH NPM\n')
    env_file.write('\nexport PATH="/usr/local/heroku/bin:$PATH"\n')
    env_file.close()
